// If we don't import, then every time we want to use the Random class, we will have to
// tell Java from which package to take it. For example (without import):
// 		java.util.Random r = new java.util.Random();
// we will almost always prefer to just import the class.
import java.util.Random;

/**
 * When you have a full project, usually bigger than your IDC exercises, the project
 * will be made of 3 types of classes:
 * - Utility classes, which are classes with only static methods and no state (state = instance variables).
 * - Entities, classes which have state and methods (static or not), and are intended to be instantiated 
 * 		by the programmer (instantiated = create objects by using 'new').
 * - The program class, which each project has 1, is where the main algorithm begins. It's the class you
 * 		run when you type 'java ClassName'.
 * 
 * In our case, the entire project can be written within the program class.
 */


/**
 * This class is the straightforward implementation of an algorithm which
 * creates random numbers and prints some statistics about it.
 * 
 * The implementation supports exactly 6 numbers to generate (1-6), with 
 * exactly 1,000 tests to generate each number.
 * If we want to change the number of possible numbers, or the number of
 * tests, it will be quite difficult for us.
 */
public class NumberStatistics {
	
	/**
	 * This is where the program begins.
	 * When we run 'java NumberStatistics', the JVM calls this statis method.
	 * If we run 'java NumberStatistics param1 param2', then param1 and param2
	 * are passed as Strings inside the 'args' array argument.
	 */
	public static void main(String[] args) {
		
		// initialize variables
		Random random = new Random();	// Random is a class in the java.util package
		int summary0 = 0;  // this will summarize all the times that the result was '0'
		int summary1 = 0;
		int summary2 = 0;
		int summary3 = 0;
		int summary4 = 0;
		int summary5 = 0;
		int counter = 0; // this will count the number of tests
		
		
		/**
		 * The difference between a 'while' loop and a 'do..while' loop is that in
		 * a 'while' loop, java first checks the boolean expression and runs the 
		 * first iteration only if it came out 'true'. In 'do..while' it first runs
		 * the first iteration, and only then checks the boolean expression.
		 * Which means: if you are SURE that you have to run the loop AT LEAST ONCE,
		 * you should probably use a 'do..while' loop.
		 */
		do {
			
			// pick a random number
			int result = random.nextInt(6); // if you're not sure what '6' means, check the api: http://docs.oracle.com/javase/6/docs/api/

			// summarize the result
			if (result == 0) {
				summary0++;
			} else if (result == 1) { // it would also work without the 'else', but it's more effective with it. why?
				summary1++;
			} else if (result == 2) {
				summary2++;
			} else if (result == 3) {
				summary3++;
			} else if (result == 4) {
				summary4++;
			} else if (result == 5) {
				summary5++;
			}

			// repeat 1,000 times
			counter++;
		} while (counter < 1000);
		
		// print statistics about each number: summary / 1,000
		System.out.println("0: %" + 100d * summary0 / 1000); // remember that int/int=int, so if you 
		System.out.println("1: %" + 100d * summary1 / 1000); // want a result that is a floating point 
		System.out.println("2: %" + 100d * summary2 / 1000); // number, cast one of the numbers to 
		System.out.println("3: %" + 100d * summary3 / 1000); // double/float (like the 100 in this case).
		System.out.println("4: %" + 100d * summary4 / 1000);
		System.out.println("5: %" + 100d * summary5 / 1000);
		
	}

}
